Test coverage report: myapp2.models

# myapp2.models: 3 total statements, 100.0% covered

Generated: Sat 2012-06-09 22:07 SGT

Source file: /Users/martin/Projects/pycon-apac-2012/tdd-with-django/reusable-app/myapp2/models.py

Stats: 2 executed, 0 missed, 1 excluded, 12 ignored

1. `"""`
2. `Models for the ``myapp2`` application.`
3. ``
4. `Before implementing anything in this file, you would create`
5. ```tests/factories.py`` and ``tests/models_tests.py``. You would use the factory`
6. `to test the creation of your model, which will fail, because the model does not`
7. `exist, then you would implement your model here.`
8. ``
9. `"""`
10. `from django.db import models`
11. ``
12. ``
13. `class Example(models.Model):`
14. `"""Example model class."""`
15. `text = models.TextField(blank=True, null=True)`